OC.L10N.register(
    "core",
    {
    "Please select a file." : "Palun vali fail.",
    "File is too big" : "Fail on liiga suur",
    "Invalid file provided" : "Vigane fail",
    "No image or file provided" : "Ühtegi pilti või faili pole pakutud",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "An error occurred. Please contact your admin." : "Tekkis tõrge. Palun võta ühendust administraatoriga.",
    "No temporary profile picture available, try again" : "Ühtegi ajutist profiili pilti pole saadaval, proovi uuesti",
    "No crop data provided" : "Lõikeandmeid ei leitud",
    "Crop is not square" : "Lõikamine pole ruudukujuline",
    "Couldn't reset password because the token is invalid" : "Ei saanud parooli taastada, kuna märgend on vigane",
    "Couldn't send reset email. Please make sure your username is correct." : "Ei suutnud lähtestada e-maili. Palun veendu, et kasutajatunnus on õige.",
    "%s password reset" : "%s parooli lähtestus",
    "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
    "Error loading tags" : "Viga siltide laadimisel",
    "Tag already exists" : "Silt on juba olemas",
    "Error deleting tag(s)" : "Viga sildi (siltide) kustutamisel",
    "Error tagging" : "Viga sildi lisamisel",
    "Error untagging" : "Viga sildi eemaldamisel",
    "Error favoriting" : "Viga lemmikuks lisamisel",
    "Error unfavoriting" : "Viga lemmikutest eemaldamisel",
    "Couldn't send mail to following users: %s " : "Kirja saatmine järgnevatele kasutajatele ebaõnnestus: %s ",
    "Preparing update" : "Uuendamise ettevalmistamine",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Paranda hoiatus:",
    "Repair error: " : "Paranda viga:",
    "Turned on maintenance mode" : "Haldusrežiimis sisse lülitatud",
    "Turned off maintenance mode" : "Haldusrežiimis välja lülitatud",
    "Maintenance mode is kept active" : "Hooldusrežiim on aktiivne",
    "Updating database schema" : "Andmebaasi skeemi uuendamine",
    "Updated database" : "Uuendatud andmebaas",
    "Checked database schema update" : "Andmebaasi skeemi uuendus kontrollitud",
    "Checked database schema update for apps" : "Andmebaasi skeemi uuendus rakendustele on kontrollitud",
    "Updated \"%s\" to %s" : "Uuendatud \"%s\" -> %s",
    "%s (3rdparty)" : "%s (3nda osapoole arendaja)",
    "%s (incompatible)" : "%s (pole ühilduv)",
    "Following apps have been disabled: %s" : "Järgnevad rakendused on välja lülitatud: %s",
    "Already up to date" : "On juba ajakohane",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Mär.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "Settings" : "Seaded",
    "Saving..." : "Salvestamine...",
    "Dismiss" : "Jäta vahele",
    "seconds ago" : "sekundit tagasi",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link parooli vahetuseks on saadetud Sinu e-posti aadressil.<br>Kui kiri pole saabunud mõistliku aja jooksul, siis kontrolli oma spam-/rämpskirjade katalooge<br>.Kui kirja pole ka seal, siis küsi abi süsteemihaldurilt.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sinu failid on krüpteeritud. Kui sa pole taastamise võtit veel määranud, siis pole präast parooli taastamist mingit võimalust sinu andmeid tagasi saada. <br />Kui sa pole kindel, mida teha, siis palun väta enne jätkamist ühendust oma administaatoriga. <br />Oled sa kindel, et sa soovid jätkata?",
    "I know what I'm doing" : "Ma tean mida teen",
    "Password can not be changed. Please contact your administrator." : "Parooli ei saa muuta. Palun kontakteeru oma süsteemihalduriga.",
    "No" : "Ei",
    "Yes" : "Jah",
    "Choose" : "Vali",
    "Error loading file picker template: {error}" : "Viga failivalija malli laadimisel:  {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Viga sõnumi malli laadimisel: {error}",
    "read-only" : "kirjutuskaitstud",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failikonflikt","{count} failikonflikti"],
    "One file conflict" : "Üks failikonflikt",
    "New Files" : "Uued failid",
    "Already existing files" : "Juba olemasolevad failid",
    "Which files do you want to keep?" : "Milliseid faile sa soovid alles hoida?",
    "If you select both versions, the copied file will have a number added to its name." : "Kui valid mõlemad versioonid, siis lisatakse kopeeritud faili nimele number.",
    "Cancel" : "Loobu",
    "Continue" : "Jätka",
    "(all selected)" : "(kõik valitud)",
    "({count} selected)" : "({count} valitud)",
    "Error loading file exists template" : "Viga faili olemasolu malli laadimisel",
    "Very weak password" : "Väga nõrk parool",
    "Weak password" : "Nõrk parool",
    "So-so password" : "Enam-vähem sobiv parool",
    "Good password" : "Hea parool",
    "Strong password" : "Väga hea parool",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Serveril puudub toimiv internetiühendus. See tähendab, et mõned funktsionaalsused, nagu näiteks väliste andmehoidlate ühendamine, teavitused uuendustest või kolmandate osapoolte rakenduste paigaldamine ei tööta. Eemalt failidele ligipääs ning teadete saatmine emailiga ei pruugi samuti toimida. Kui soovid täielikku funktsionaalsust, siis soovitame serverile tagada ligipääs internetti.",
    "Error occurred while checking server setup" : "Serveri seadete kontrolimisel tekkis viga",
    "Shared" : "Jagatud",
    "Shared with {recipients}" : "Jagatud {recipients}",
    "Error" : "Viga",
    "Error while sharing" : "Viga jagamisel",
    "Error while unsharing" : "Viga jagamise lõpetamisel",
    "Error setting expiration date" : "Viga aegumise kuupäeva määramisel",
    "The public link will expire no later than {days} days after it is created" : "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Expiration" : "Aegumine",
    "Expiration date" : "Aegumise kuupäev",
    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Share link" : "Jaga linki",
    "Link" : "Link",
    "Password protect" : "Parooliga kaitstud",
    "Password" : "Parool",
    "Allow editing" : "Luba muutmine",
    "Email link to person" : "Saada link isikule e-postiga",
    "Send" : "Saada",
    "Sending ..." : "Saatmine ...",
    "Email sent" : "E-kiri on saadetud",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
    "Shared with you by {owner}" : "Sinuga jagas {owner}",
    "group" : "grupp",
    "notify by email" : "teavita e-postiga",
    "Unshare" : "Lõpeta jagamine",
    "can share" : "saab jagada",
    "can edit" : "saab muuta",
    "create" : "loo",
    "change" : "muuda",
    "delete" : "kustuta",
    "access control" : "ligipääsukontroll",
    "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
    "{sharee} (group)" : "{sharee} (group)",
    "{sharee} (at {server})" : "{sharee} (serveris {server})",
    "{sharee} (remote)" : "{sharee} (mujal serveris)",
    "Share" : "Jaga",
    "Warning" : "Hoiatus",
    "Error while sending notification" : "Tõrge teavituse saatmisel",
    "invisible" : "nähtamatu",
    "({scope})" : "({scope})",
    "Delete" : "Kustuta",
    "Rename" : "Nimeta ümber",
    "The object type is not specified." : "Objekti tüüp pole määratletud.",
    "Enter new" : "Sisesta uus",
    "Add" : "Lisa",
    "Edit tags" : "Muuda silte",
    "Error loading dialog template: {error}" : "Viga dialoogi malli laadimisel: {error}",
    "No tags selected for deletion." : "Kustutamiseks pole ühtegi silti valitud.",
    "unknown text" : "tundmatu tekst",
    "Hello world!" : "Tere maailm!",
    "sunny" : "päikeseline",
    "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
    "Hello {name}" : "Tere, {name}",
    "new" : "uus",
    "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
    "Updating to {version}" : "Uuendamine versioonile {version}",
    "An error occurred." : "Tekkis tõrge.",
    "Please reload the page." : "Palun laadi see uuesti.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Uuendus ebaõnnestus. Palun teavita probleemidest  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud kogukonda</a>.",
    "The update was successful. There were warnings." : "Uuendamine läks kenasti. hoiatusi polnud.",
    "The update was successful. Redirecting you to ownCloud now." : "Uuendus oli edukas. Kohe suunatakse Sind ownCloudi.",
    "Searching other places" : "Otsi teistest kohtadest",
    "Personal" : "Isiklik",
    "Users" : "Kasutajad",
    "Apps" : "Rakendused",
    "Admin" : "Admin",
    "Help" : "Abiinfo",
    "Access forbidden" : "Ligipääs on keelatud",
    "File not found" : "Faili ei leitud",
    "The specified document has not been found on the server." : "Määratud dokumenti serverist ei leitud.",
    "You can click here to return to %s." : "%s tagasi minemiseks võid sa siia klikkida.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Tere,\n\n%s jagas sulle välja %s.\nVaata siit: %s\n\n",
    "The share will expire on %s." : "Jagamine aegub %s.",
    "Cheers!" : "Terekest!",
    "Internal Server Error" : "Serveri sisemine viga",
    "The server encountered an internal error and was unable to complete your request." : "Serveris tekkis sisemine tõrge ja sinu päringu täitmine ebaõnnestus.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Kui seda veateadet näidatakse mitu korda, siis palun võta ühendust serveri administraatoriga. Palun lisa alla aruandesse tehnilised üksikasjad.",
    "More details can be found in the server log." : "Lisainfot võib leida serveri logist.",
    "Technical details" : "Tehnilised andmed",
    "Remote Address: %s" : "Kaugaadress: %s",
    "Request ID: %s" : "Päringu ID: %s",
    "Type: %s" : "Tüüp: %s",
    "Code: %s" : "Kood: %s",
    "Message: %s" : "Sõnum: %s",
    "File: %s" : "Fail: %s",
    "Line: %s" : "Rida: %s",
    "Trace" : "Jälita",
    "Security warning" : "Turvahoiatus",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmete kataloog ja failid on tõenäoliselt internetist vabalt saadaval kuna .htaccess fail ei toimi.",
    "Create an <strong>admin account</strong>" : "Loo <strong>admini konto</strong>",
    "Username" : "Kasutajanimi",
    "Storage & database" : "Andmehoidla ja andmebaas",
    "Data folder" : "Andmete kaust",
    "Configure the database" : "Seadista andmebaasi",
    "Only %s is available." : "Ainult %s on saadaval.",
    "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
    "Database user" : "Andmebaasi kasutaja",
    "Database password" : "Andmebaasi parool",
    "Database name" : "Andmebasi nimi",
    "Database tablespace" : "Andmebaasi tabeliruum",
    "Database host" : "Andmebaasi host",
    "Performance warning" : "Kiiruse hoiatus",
    "SQLite will be used as database." : "Andmebaasina kasutatakse SQLite",
    "Finish setup" : "Lõpeta seadistamine",
    "Finishing …" : "Lõpetamine ...",
    "Need help?" : "Vajad abi?",
    "See the documentation" : "Vaata dokumentatsiooni",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei,<br><br>annan teada, et %s jagas sinuga <strong>%s</strong>. <a href=\"%s\">Vaata seda!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
    "Log out" : "Logi välja",
    "Search" : "Otsi",
    "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
    "Please contact your administrator." : "Palun kontakteeru oma süsteemihalduriga.",
    "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
    "Log in" : "Logi sisse",
    "Wrong password. Reset it?" : "Vale parool. Kas vajad parooli taastamist?",
    "Wrong password." : "Vale parool.",
    "Stay logged in" : "Püsi sisselogituna",
    "Alternative Logins" : "Alternatiivsed sisselogimisviisid",
    "Use the following link to reset your password: {link}" : "Kasuta järgnevat linki oma parooli taastamiseks: {link}",
    "New password" : "Uus parool",
    "New Password" : "Uus parool",
    "Reset password" : "Nulli parool",
    "This ownCloud instance is currently in single user mode." : "See ownCloud on momendil seadistatud ühe kasutaja jaoks.",
    "This means only administrators can use the instance." : "See tähendab, et seda saavad kasutada ainult administraatorid.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakteeru oma süsteemihalduriga, kui see teade püsib või on tekkinud ootamatult.",
    "Thank you for your patience." : "Täname kannatlikkuse eest.",
    "You are accessing the server from an untrusted domain." : "Sa kasutad serverit usalduseta asukohast",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Sõltuvalt sinu seadetest võib ka administraator kasutada allolevat nuppu, et seda domeeni usaldusväärseks märkida.",
    "Add \"%s\" as trusted domain" : "Lisa \"%s\" usaldusväärse domeenina",
    "App update required" : "Rakenduse uuendus on nõutud",
    "These apps will be updated:" : "Neid rakendusi uuendatakse:",
    "These incompatible apps will be disabled:" : "Need mitteühilduvad rakendused lülitatakse välja:",
    "The theme %s has been disabled." : "Teema %s on keelatud.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas, seadete ning andmete kataloog on varundatud.",
    "Start update" : "Käivita uuendus",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
    "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval."
},
"nplurals=2; plural=(n != 1);");
